Documentation
¶
Overview ¶
Package cmd contains the commands for the app.
Package cmd contains the commands for the app.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute(ui http.FileSystem)
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.